Crusade: Philadelphia Philadelphia November 4th 2000 Josh Duffin http://groups.yahoo.com/neo/groups/vtes/conversations/messages/490 Gangrel Wall of Untap Josh's deck is a fiendishly clever block and untap monstrosity. Cats Guidance, Raven Spies, Forced Awakenings, and Atonement make for constant blocks, and Earth Meld keeps your people alive and ready for more. Smiling Jack the Anarch takes down entire tables while pool management keeps his damage to you to a minimum. Millicent Smith, Puritan Vampire Hunter is also a really nice addition to this blocking machine. (I didn't get Josh's comments on the final, or on his deck, so I hope he'll respond to this mail with any words of wisdom on playing this thing.) Crypt (12 cards, min=14, max=32, avg=5.5) ----------------------------------------- 2x Bear Paw 5 ANI for pre pro Gangrel:1 1x Camille Devereux 5 FOR PRO ani Gangrel:1 1x Raven 5 FOR PRO ani Gangrel:1 2x Chandler Hungerford 3 PRO Gangrel:2 1x Basilia 10 ANI FOR PRO obf pot primogen Gangrel:1 1x Ingrid Rossler 9 ANI FOR PRO dom prince Gangrel:2 1x Gitane St. Claire 7 ANI FOR PRO primogen Gangrel:1 1x Badger 6 FOR PRO ani pot Gangrel:1 1x Mirembe Kabbada 5 PRO SER ani Gangrel:2 1x Anastasia Grey 3 ani pro Gangrel:1 Library (90 cards) Master (27) 2x Animalism 4x Blood Doll 3x Blood Puppy 2x Ecoterrorists 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 3x Millicent Smith, Puritan Vampire Hunter 2x Parthenon, The 1x Powerbase: Chicago 1x Protean 2x Rack, The 3x Smiling Jack, The Anarch 2x Zoo Hunting Ground Action (7) 3x Army of Rats 2x Atonement 1x Restoration 1x Shepherd's Innocence Equipment (5) 2x Flak Jacket 1x Palatial Estate 2x Sport Bike Retainer (5) 1x Homunculus 1x Mr. Winthrop 3x Raven Spy Action Modifier (2) 2x Earth Control Reaction (18) 10x Cats' Guidance 7x Forced Awakening 1x Wake with Evening's Freshness Combat (26) 2x Bone Spur 2x Canine Horde 15x Earth Meld -- ! 3x Form of Mist 3x Superior Mettle 1x Wolf Claws